@@ -1,6 +1,6 @@
 import           Data.Tagged          (Tagged (..), untag)
 
-import           Test.Framework       (Test, defaultMain, testGroup)
+import           Test.Tasty           (TestTree, defaultMain, testGroup)
 
 import qualified Data.HashPSQ         as HashPSQ
 import qualified Data.HashPSQ.Tests
@@ -12,7 +12,7 @@ import qualified Data.PSQ.Class.Tests
 import           Data.PSQ.Class.Util
 
 main :: IO ()
-main = defaultMain
+main = defaultMain $ testGroup "psqueues"
     [ testGroup "Data.IntPSQ.Tests"
         Data.IntPSQ.Tests.tests
     , testGroup "Data.HashPSQ.Tests"
@@ -21,11 +21,11 @@ main = defaultMain
         Data.OrdPSQ.Tests.tests
     , testGroup "Data.PSQ.Class.Tests IntPSQ"  $ untag
         (Data.PSQ.Class.Tests.tests
-            :: Tagged IntPSQ.IntPSQ [Test])
+            :: Tagged IntPSQ.IntPSQ [TestTree])
     , testGroup "Data.PSQ.Class.Tests PSQ"     $ untag
         (Data.PSQ.Class.Tests.tests
-            :: Tagged (OrdPSQ.OrdPSQ Int) [Test])
+            :: Tagged (OrdPSQ.OrdPSQ Int) [TestTree])
     , testGroup "Data.PSQ.Class.Tests HashPSQ" $ untag
         (Data.PSQ.Class.Tests.tests
-            :: Tagged (HashPSQ.HashPSQ LousyHashedInt) [Test])
+            :: Tagged (HashPSQ.HashPSQ LousyHashedInt) [TestTree])
     ]
